@@ -42,7 +42,7 @@
 #include <stdint.h>
 
 #if HAVE_PCAP_H
-# include <pcap.h>
+#include <pcap.h>
 #endif
 
 #define DNS_MSG_HDR_SZ 12
@@ -51,40 +51,41 @@
 #define MAX_QNAME_SZ 512
 
 struct rfc1035_header_s {
-    uint16_t id;
-    unsigned int qr:1;
-    unsigned int opcode:4;
-    unsigned int aa:1;
-    unsigned int tc:1;
-    unsigned int rd:1;
-    unsigned int ra:1;
-    unsigned int z:1;
-    unsigned int ad:1;
-    unsigned int cd:1;
-    unsigned int rcode:4;
-    uint16_t qdcount;
-    uint16_t ancount;
-    uint16_t nscount;
-    uint16_t arcount;
-    uint16_t qtype;
-    uint16_t qclass;
-    char     qname[MAX_QNAME_SZ];
-    uint16_t length;
+  uint16_t id;
+  unsigned int qr : 1;
+  unsigned int opcode : 4;
+  unsigned int aa : 1;
+  unsigned int tc : 1;
+  unsigned int rd : 1;
+  unsigned int ra : 1;
+  unsigned int z : 1;
+  unsigned int ad : 1;
+  unsigned int cd : 1;
+  unsigned int rcode : 4;
+  uint16_t qdcount;
+  uint16_t ancount;
+  uint16_t nscount;
+  uint16_t arcount;
+  uint16_t qtype;
+  uint16_t qclass;
+  char qname[MAX_QNAME_SZ];
+  uint16_t length;
 };
 typedef struct rfc1035_header_s rfc1035_header_t;
 
 #if HAVE_PCAP_H
-void dnstop_set_pcap_obj (pcap_t *po);
+void dnstop_set_pcap_obj(pcap_t *po);
 #endif
-void dnstop_set_callback (void (*cb) (const rfc1035_header_t *));
+void dnstop_set_callback(void (*cb)(const rfc1035_header_t *));
 
-void ignore_list_add_name (const char *name);
+void ignore_list_add_name(const char *name);
 #if HAVE_PCAP_H
-void handle_pcap (u_char * udata, const struct pcap_pkthdr *hdr, const u_char * pkt);
+void handle_pcap(u_char *udata, const struct pcap_pkthdr *hdr,
+                 const u_char *pkt);
 #endif
 
 const char *qtype_str(int t);
 const char *opcode_str(int o);
-const char *rcode_str (int r);
+const char *rcode_str(int r);
 
 #endif /* !COLLECTD_UTILS_DNS_H */
